===============================
networking-brocade
===============================

Brocade Networking Mech. Drivers and Plugins

* Free software: Apache license
* Source: http://git.openstack.org/cgit/stackforge/networking-brocade

Features
--------

* TODO
